describe Inkcite::Renderer::List do

  before do
    @view = Inkcite::Email.new('test/project/').view(:development, :email)
  end

  it 'renders a bullet list' do
    Inkcite::Renderer.render('{ul}{li}Item 1{/li}{/ul}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td>Item 1</td></tr></table>')
  end

  it 'renders space between list items' do
    Inkcite::Renderer.render('{ul}{li}Item 1{/li}{li}Item 2{/li}{/ul}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td>Item 1<div style="font-size:3px;height:3px;line-height:3px">&nbsp;</div></td></tr><tr><td valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td>Item 2</td></tr></table>')
  end

  it 'supports customizable space between list items' do
    Inkcite::Renderer.render('{ul spacing=15}{li}Item 1{/li}{li}Item 2{/li}{li}Item 3{/li}{/ul}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td>Item 1<div style="font-size:15px;height:15px;line-height:15px">&nbsp;</div></td></tr><tr><td valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td>Item 2<div style="font-size:15px;height:15px;line-height:15px">&nbsp;</div></td></tr><tr><td valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td>Item 3</td></tr></table>')
  end

  it 'supports customizable fonts' do
    Inkcite::Renderer.render('{ul font-size=15}{li}Item 1{/li}{li}Item 2{/li}{/ul}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td style="font-size:15px" valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td style="font-size:15px">Item 1<div style="font-size:3px;height:3px;line-height:3px">&nbsp;</div></td></tr><tr><td style="font-size:15px" valign=top>&nbsp;&nbsp;&bull;&nbsp;</td><td style="font-size:15px">Item 2</td></tr></table>')
  end

  it 'supports customizable bullets' do
    Inkcite::Renderer.render('{ul bullet="☆"}{li}Item 1{/li}{li}Item 2{/li}{/ul}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td valign=top>&nbsp;&nbsp;☆&nbsp;</td><td>Item 1<div style="font-size:3px;height:3px;line-height:3px">&nbsp;</div></td></tr><tr><td valign=top>&nbsp;&nbsp;☆&nbsp;</td><td>Item 2</td></tr></table>')
  end

  it 'supports numbered lists' do
    Inkcite::Renderer.render('{ol}{li}Item 1{/li}{li}Item 2{/li}{/ol}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td valign=top>&nbsp;&nbsp;1.&nbsp;</td><td>Item 1<div style="font-size:3px;height:3px;line-height:3px">&nbsp;</div></td></tr><tr><td valign=top>&nbsp;&nbsp;2.&nbsp;</td><td>Item 2</td></tr></table>')
  end

  it 'supports bullet-free lists' do
    Inkcite::Renderer.render('{ul bullet=none}{li}Item 1{/li}{li}Item 2{/li}{/ul}', @view).must_equal('<table border=0 cellpadding=0 cellspacing=0><tr><td>Item 1<div style="font-size:3px;height:3px;line-height:3px">&nbsp;</div></td></tr><tr><td>Item 2</td></tr></table>')

  end

end
